/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect } from 'react'
import { fetchAllRequest, getRequest } from '../../HelperFunctions/getAxiosConfig'
import PanelTemplateColecao from '../PanelComponents/TemplateColecao.js'
import LoadingSpinner from '../../LoadingSpinner.js'

export default function TabColecoes({id, username}) {
    const [loading, handleLoading] = useState(true)

    const [errorInUserColl, setErrorInUserColl] = useState(false)
  
    const [userCollections, setUserCollections] = useState([])
  
    const [currLimitUserColl, setCurrLimitUserColl] = useState(4)
  
    const [loadingMoreUserColl, setLoadingMoreUserColl] = useState(false);
  
    const [endOfUserColl, setEndOfUserColl] = useState(false);
  
    function handleSuccess(responseArr, headersArr) {
      setErrorInUserColl(responseArr[0].errors ? true : false)
  
      handleLoading(false)
      setUserCollections(responseArr[0])
  
      if (headersArr[0].has('X-Total-Count')) {
        setEndOfUserColl(headersArr[0].get('X-Total-Count'));
      }
    }
  
    function handleError(error) {
      handleLoading(false)
      setErrorInUserColl(true)
    }
  
    const getInfo = () => {
      const urls = [
        `/users/${id}/collections?offset=0&limit=4`,
      ]
      fetchAllRequest(urls, handleSuccess, handleError)
    }
  
    useEffect(() => {
      handleLoading(true)
      getInfo()
    }, [])
  
    const showMoreUserCollections = (limite) => {
      const limit = limite;
      setLoadingMoreUserColl(true);
      setCurrLimitUserColl(currLimitUserColl + limit)
      const url = `/users/${id}/collections?offset=${currLimitUserColl}&limit=${limit}`;
      getRequest(url,
        (data) => {
          if (data.errors) {
            setLoadingMoreUserColl(false);
            setEndOfUserColl(true)
            setErrorInUserColl(true)
          }
          else if (data.length >= 1) {
            let currData = [...userCollections];
            currData = [...currData.concat(data)];
            setLoadingMoreUserColl(false);
            setUserCollections(currData);
          }
          else {
            setLoadingMoreUserColl(false);
            setEndOfUserColl(true)
          }
        },
        (error) => {
          setLoadingMoreUserColl(false);
          setEndOfUserColl(true)
          setErrorInUserColl(true)
        }
      )
    }

    return (
        <>
            {
                loading ?
                (
                    <LoadingSpinner text={`Carregando coleções de ${username}`} />
                )
                :
                (
                    <PanelTemplateColecao
                        title={"Coleções Públicas"}
                        length={userCollections.length}
                        noContentText={username + " não possui nenhuma coleção."}
                        sliceArr={userCollections}
                        showMore={showMoreUserCollections}
                        loadingMore={loadingMoreUserColl}
                        end={endOfUserColl}
                        followed={false}
                        error={errorInUserColl}
                    />
                )
            }
        </>
    )
}
